@@ -10,6 +10,7 @@ from wf_core_data_dashboard.core import get_template
 
 import wf_core_data_dashboard.assessments.fastbridge
 import wf_core_data_dashboard.assessments.nwea
+import wf_core_data_dashboard.assessments.mefs
 
 class StatusResponse(BaseModel):
     status: str = "OK"
@@ -67,6 +68,29 @@ students_nwea, groups_nwea = wf_core_data_dashboard.assessments.nwea.generate_nw
     student_assignments_path_nwea
 )
 
+data_directory_mefs = "./data/analysis/mefs_analysis/mefs_analysis_20211008"
+
+test_events_path_mefs = os.path.join(
+    data_directory_mefs,
+    'test_events_20211008.pkl'
+)
+
+student_info_path_mefs = os.path.join(
+    data_directory_mefs,
+    'student_info_20211008.pkl'
+)
+
+student_assignments_path_mefs = os.path.join(
+    data_directory_mefs,
+    'student_assignments_20211008.pkl'
+)
+
+students_mefs, groups_mefs = wf_core_data_dashboard.assessments.mefs.generate_mefs_table_data(
+    test_events_path_mefs,
+    student_info_path_mefs,
+    student_assignments_path_mefs
+)
+
 
 ########################################################################
 # Routes
@@ -74,9 +98,14 @@ students_nwea, groups_nwea = wf_core_data_dashboard.assessments.nwea.generate_nw
 @router.get("/", response_class=HTMLResponse)
 async def index():
     template = get_template("index.html")
-    return template.render(title="Assessment Results",
-                           subtitle="Available Reports")
+    return template.render(title="Assessment results",
+                           subtitle="Available assessments")
 
+@router.get("/fastbridge", response_class=HTMLResponse)
+async def fastbridge_overview():
+    template = get_template("fastbridge_overview.html")
+    return template.render(title="FastBridge results",
+                           subtitle="Available reports")
 
 @router.get("/fastbridge/groups/", response_class=HTMLResponse)
 async def fastbridge_groups_page(
@@ -108,6 +137,12 @@ async def fastbridge_students_page(
         subtest=subtest
     )
 
+@router.get("/nwea", response_class=HTMLResponse)
+async def fastbridge_overview():
+    template = get_template("nwea_overview.html")
+    return template.render(title="NWEA results",
+                           subtitle="Available reports")
+
 @router.get("/nwea/groups/", response_class=HTMLResponse)
 async def nwea_groups_page(
     school_year: Optional[str]=None,
@@ -137,3 +172,31 @@ async def nwea_students_page(
         subject=subject,
         course=course
     )
+
+@router.get("/mefs", response_class=HTMLResponse)
+async def fastbridge_overview():
+    template = get_template("mefs_overview.html")
+    return template.render(title="MEFS results",
+                           subtitle="Available reports")
+
+@router.get("/mefs/groups/", response_class=HTMLResponse)
+async def mefs_groups_page(
+    school_year: Optional[str]=None,
+    group_name_mefs: Optional[str]=None
+):
+    return wf_core_data_dashboard.assessments.mefs.groups_page_html(
+        groups_mefs,
+        school_year=school_year,
+        group_name_mefs=group_name_mefs
+    )
+
+@router.get("/mefs/students/", response_class=HTMLResponse)
+async def mefs_students_page(
+    school_year: Optional[str]=None,
+    group_name_mefs: Optional[str]=None
+):
+    return wf_core_data_dashboard.assessments.mefs.students_page_html(
+        students=students_mefs,
+        school_year=school_year,
+        group_name_mefs=group_name_mefs
+    )
